clj-concordion.internal.utils


->defnclj

(->defn prefix v)
source

arg->typeclj

(arg->type arg)
source

var->arglistclj

(var->arglist v)
source

var->metaclj

(var->meta v)
source

var->method-descrclj

(var->method-descr v)

Get arg and return types of the given fn; v is a var Ex.: (fn->typesadd)` => {:namesym add :args [Integer Integer], :ret java.lang.Integer}

Get arg and return types of the given fn; v is a var
Ex.: `(fn->types `add)` =>
 {:namesym add :args [Integer Integer], :ret java.lang.Integer}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries