(var->method-descr v)Get arg and return types of the given fn; v is a var
Ex.: (fn->typesadd)` =>
{:namesym add :args [Integer Integer], :ret java.lang.Integer}
Get arg and return types of the given fn; v is a var
Ex.: `(fn->types `add)` =>
{:namesym add :args [Integer Integer], :ret java.lang.Integer}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |